@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.72 2005/07/11 19:23:35 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.73 2005/08/22 14:58:47 richb Exp $
  *
  *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -450,7 +450,7 @@ void make_reg(int, char *);
 void make_registers();
 void mperr();
 void MPstr_to_num(char *, enum base_type, int *);
-void paren_disp(char);
+void paren_disp(int);
 void process_item(struct button *);
 void process_str(char *);
 void push_num(int *);
