@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.58 2005/04/11 17:38:33 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.59 2005/08/22 14:58:47 richb Exp $
  *
  *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -442,7 +442,7 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
 /* Append the latest parenthesis char to the display item. */
 
 void
-paren_disp(char c)
+paren_disp(int c)
 {
     int i, n;
 
